@@ -432,7 +432,7 @@ impl<'a> Emitter<'a> {
             self.wr.write_str_lit(num.span, "Infinity")?;
         } else {
             if num.value.is_sign_negative() && num.value == 0.0 {
-                self.wr.write_str_lit(num.span, "-0.0")?;
+                self.wr.write_str_lit(num.span, "-0")?;
             } else {
                 self.wr.write_str_lit(num.span, &format!("{}", num.value))?;
             }
